A few more replacements for canManageTeam.
[timetracker.git] / users.php
index 1233f11..79f2df3 100644 (file)
--- a/users.php
+++ b/users.php
@@ -30,9 +30,10 @@ require_once('initialize.php');
 import('form.Form');
 import('ttTeamHelper');
 import('ttTimeHelper');
+import('ttRoleHelper');
 
 // Access check.
-if (!ttAccessCheck(right_data_entry)) {
+if (!ttAccessAllowed('view_users')) {
   header('Location: access_denied.php');
   exit();
 }
@@ -40,13 +41,22 @@ if (!ttAccessCheck(right_data_entry)) {
 // Get users.
 $active_users = ttTeamHelper::getActiveUsers(array('getAllFields'=>true));
 if($user->canManageTeam()) {
+
+  // If there are no roles in team, introduce default ones.
+  if (!ttRoleHelper::rolesExist()) ttRoleHelper::createDefaultRoles(); // TODO: refactor or remove after roles revamp.
+  // This is here temporarily so that we have roles to work with to manage users.
+  // Normally, this should be done during an upgrade step (not yet implemented).
+
   $can_delete_manager = (1 == count($active_users));
   $inactive_users = ttTeamHelper::getInactiveUsers($user->team_id, true);
 }
 
-// Check each active user if they have an uncompleted time entry.
-foreach ($active_users as $key => $user) {
-  $active_users[$key]['has_uncompleted_entry'] = (bool) ttTimeHelper::getUncompleted($user['id']);
+// Check if the team is set to show indicators for uncompleted time entries.
+if ($user->uncompleted_indicators) {
+  // Check each active user if they have an uncompleted time entry.
+  foreach ($active_users as $key => $user) {
+    $active_users[$key]['has_uncompleted_entry'] = (bool) ttTimeHelper::getUncompleted($user['id']);
+  }
 }
 
 $smarty->assign('active_users', $active_users);